import { Ref, onBeforeUnmount, onMounted, ref } from 'vue'
import { addResizeListener, removeResizeListener } from '../dom'
import { debounce } from 'lodash-es'

export default function useElTableColumnWidth(
  selector: string,
): [Ref<HTMLElement | null>, Ref<number>] {
  const tableWrapperRef = ref<HTMLDivElement | null>(null)
  let cleanupResizeEventListener: (() => void) | undefined
  const width = ref(0)

  const onThOrderDetailResize = debounce(() => {
    const el = tableWrapperRef.value
    if (!el) return
    const th = el.querySelector(selector) as HTMLElement | null
    if (th) {
      width.value = th.offsetWidth
    }
  }, 50)

  onMounted(() => {
    const el = tableWrapperRef.value
    if (!el) return
    cleanupResizeEventListener = () => {
      removeResizeListener(el, onThOrderDetailResize)
    }
    addResizeListener(el, onThOrderDetailResize)
  })

  onBeforeUnmount(() => {
    cleanupResizeEventListener?.()
  })

  return [tableWrapperRef, width]
}
